==> 3.5.12-core.tar: kdelibs/kdeprint/cups/cupsdconf2/editlist.h <==
/*
 *  This file is part of the KDE libraries
 *  Copyright (c) 2001 Michael Goffioul <kdeprint@swing.be>
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public
 *  License version 2 as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public License
 *  along with this library; see the file COPYING.LIB.  If not, write to
 *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 *  Boston, MA 02110-1301, USA.
 **/

#ifndef EDITLIST_H
#define EDITLIST_H

#include <tqwidget.h>
#include <tqpixmap.h>

class KListBox;
class TQPushButton;

class EditList : public QWidget
{
	Q_OBJECT

public:
	EditList(TQWidget *parent = 0, const char *name = 0);

	TQString text(int);
	void setText(int, const TQString&);
	void insertItem(const TQString&);
	void insertItem(const TQPixmap&, const TQString&);
	void insertItems(const TQStringList&);
	TQStringList items();
	void clear();

signals:
	void add();
	void edit(int);
	void defaultList();
	void deleted(int);

protected slots:
	void slotDelete();
	void slotEdit();
	void slotSelected(int);

private:
	KListBox	*list_;
	QPushButton	*addbtn_, *editbtn_, *delbtn_, *defbtn_;
};

#endif

==> 3.5.13-core.tar: kdelibs/kdeprint/cups/cupsdconf2/editlist.h <==
/*
 *  This file is part of the KDE libraries
 *  Copyright (c) 2001 Michael Goffioul <kdeprint@swing.be>
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public
 *  License version 2 as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public License
 *  along with this library; see the file COPYING.LIB.  If not, write to
 *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 *  Boston, MA 02110-1301, USA.
 **/

#ifndef EDITLIST_H
#define EDITLIST_H

#include <tqwidget.h>
#include <tqpixmap.h>

class KListBox;
class TQPushButton;

class EditList : public TQWidget
{
	Q_OBJECT

public:
	EditList(TQWidget *parent = 0, const char *name = 0);

	TQString text(int);
	void setText(int, const TQString&);
	void insertItem(const TQString&);
	void insertItem(const TQPixmap&, const TQString&);
	void insertItems(const TQStringList&);
	TQStringList items();
	void clear();

signals:
	void add();
	void edit(int);
	void defaultList();
	void deleted(int);

protected slots:
	void slotDelete();
	void slotEdit();
	void slotSelected(int);

private:
	KListBox	*list_;
	TQPushButton	*addbtn_, *editbtn_, *delbtn_, *defbtn_;
};

#endif
